@@ -15,4 +15,8 @@ class setup:
         print(message)
         print()
         if self.raise_error:
-            raise Exception('Raiser') from exception
\ No newline at end of file
+            raise Exception('Raiser') from exception
+    def send_message(self, message):
+        self.bot.send_message(self.channel, message)
+        print(message)
+        print()
\ No newline at end of file
